@@ -45,10 +45,10 @@ DummyBackend::DummyBackend(QObject* parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(new DummyReviewsBackend(this))
     , m_fetching(true)
-    , m_startElements(320)
+    , m_startElements(120)
 {
     QTimer::singleShot(500, this, &DummyBackend::toggleFetching);
-    connect(m_reviews, &DummyReviewsBackend::ratingsReady, this, &DummyBackend::allDataChanged);
+    connect(m_reviews, &DummyReviewsBackend::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
 }
 
 void DummyBackend::setMetaData(const QString& path)
@@ -91,9 +91,9 @@ void DummyBackend::setMetaData(const QString& path)
 
 void DummyBackend::populate(const QString& n)
 {
-    int start = m_resources.count();
+    const int start = m_resources.count();
     for(int i=start; i<start+m_startElements; i++) {
-        QString name = n+QLatin1Char(' ')+QString::number(i);
+        const QString name = n+QLatin1Char(' ')+QString::number(i);
         DummyResource* res = new DummyResource(name, false, this);
         res->setState(AbstractResource::State(1+(i%3)));
         m_resources.insert(name, res);
@@ -101,7 +101,7 @@ void DummyBackend::populate(const QString& n)
     }
 
     for(int i=start; i<start+m_startElements; i++) {
-        QString name = QStringLiteral("techie")+QString::number(i);
+        const QString name = QStringLiteral("techie")+QString::number(i);
         DummyResource* res = new DummyResource(name, true, this);
         res->setState(AbstractResource::State(1+(i%3)));
         m_resources.insert(name, res);
@@ -131,17 +131,7 @@ QVector<AbstractResource*> DummyBackend::allResources() const
 
 int DummyBackend::updatesCount() const
 {
-    return upgradeablePackages().count();
-}
-
-QList<AbstractResource*> DummyBackend::upgradeablePackages() const
-{
-    QList<AbstractResource*> updates;
-    foreach(AbstractResource* res, m_resources) {
-        if(res->state()==AbstractResource::Upgradeable)
-            updates += res;
-    }
-    return updates;
+    return m_updater->updatesCount();
 }
 
 AbstractResource* DummyBackend::resourceByPackageName(const QString& name) const
@@ -169,7 +159,7 @@ AbstractReviewsBackend* DummyBackend::reviewsBackend() const
     return m_reviews;
 }
 
-void DummyBackend::installApplication(AbstractResource* app, AddonList addons)
+void DummyBackend::installApplication(AbstractResource* app, const AddonList& addons)
 {
     TransactionModel *transModel = TransactionModel::global();
     transModel->addTransaction(new DummyTransaction(qobject_cast<DummyResource*>(app), addons, Transaction::InstallRole));
@@ -187,9 +177,6 @@ void DummyBackend::removeApplication(AbstractResource* app)
 	transModel->addTransaction(new DummyTransaction(qobject_cast<DummyResource*>(app), Transaction::RemoveRole));
 }
 
-void DummyBackend::cancelTransaction(AbstractResource*)
-{}
-
 void DummyBackend::checkForUpdates()
 {
     if(m_fetching)
