@@ -54,7 +54,8 @@ void DummyReviewsBackend::initialize()
     foreach(AbstractResource* app, b->allResources()) {
         if (m_ratings.contains(app))
             continue;
-        Rating* rating = new Rating(app->packageName(), app->name(), 15, qrand()%15, QStringLiteral("\"0, 0, 0, 4, %1\"").arg(qrand()%15));
+        auto randomRating = qrand()%10;
+        Rating* rating = new Rating(app->packageName(), 15, randomRating, QStringLiteral("\"0, 0, 0, 4, %1\"").arg(randomRating));
         rating->setParent(this);
         m_ratings.insert(app, rating);
     }
