@@ -54,15 +54,14 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void installApplication(AbstractResource* app) override;
         void installApplication(AbstractResource* app, const AddonList& addons) override;
         void removeApplication(AbstractResource* app) override;
-        void cancelTransaction(AbstractResource* app) override;
         bool isValid() const override { return true; }
-        QList<AbstractResource*> upgradeablePackages() const override;
+        QSet<AbstractResource*> upgradeablePackages() const;
         bool isFetching() const override;
         QList<QAction*> messageActions() const override;
 
         bool isPackageNameUpgradeable(const PackageKitResource* res) const;
         QString upgradeablePackageId(const PackageKitResource* res) const;
-        QVector<AbstractResource*> resourcesByPackageName(const QString& name, bool updating) const;
+        QSet<AbstractResource*> resourcesByPackageName(const QString& name) const;
         QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
         void fetchUpdates();
 
@@ -85,6 +84,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void addTransaction(PKTransaction* trans);
         void checkDaemonRunning();
         void acquireFetching(bool f);
+        void includePackagesToAdd();
 
         Appstream::Database m_appdata;
         QList<Transaction*> m_transactions;
@@ -92,6 +92,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QPointer<PackageKit::Transaction> m_refresher;
         int m_isFetching;
         QSet<QString> m_updatesPackageId;
+        QSet<PackageKitResource*> m_packagesToAdd;
+        QSet<PackageKitResource*> m_packagesToDelete;
         QList<QAction*> m_messageActions;
 
         struct Packages {
@@ -102,7 +104,6 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         };
 
         Packages m_packages;
-        Packages m_updatingPackages;
         AppstreamReviews* const m_reviews;
 };
 
