@@ -68,6 +68,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QStringList mimetypes READ mimetypes CONSTANT)
     Q_PROPERTY(AbstractResourcesBackend* backend READ backend CONSTANT)
     Q_PROPERTY(Rating* rating READ rating NOTIFY ratingFetched)
+    Q_PROPERTY(QString appstreamId READ appstreamId CONSTANT)
     public:
         /**
          * This describes the state of the resource
@@ -90,7 +91,7 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
              */
             Upgradeable
         };
-        Q_ENUMS(State)
+        Q_ENUM(State)
 
         /**
          * Constructs the AbstractResource with its corresponding backend
@@ -147,6 +148,10 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
 
         virtual QStringList executables() const;
 
+        virtual QStringList extends() const;
+
+        virtual QString appstreamId() const;
+
         bool canUpgrade();
         bool isInstalled();
 
@@ -182,6 +187,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
         void changelogFetched(const QString& changelog);
 
     private:
+        void reportNewState();
+
 //         TODO: make it std::optional or make QCollatorSortKey()
         QScopedPointer<QCollatorSortKey> m_collatorKey;
 };
