@@ -39,8 +39,9 @@ ResourcesUpdatesModel::ResourcesUpdatesModel(QObject* parent)
     , m_lastIsProgressing(false)
     , m_transaction(nullptr)
 {
-    init();
     connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, this, &ResourcesUpdatesModel::init);
+
+    init();
 }
 
 void ResourcesUpdatesModel::init()
@@ -56,7 +57,6 @@ void ResourcesUpdatesModel::init()
             connect(updater, &AbstractBackendUpdater::statusDetailChanged, this, &ResourcesUpdatesModel::statusDetailChanged);
             connect(updater, &AbstractBackendUpdater::remainingTimeChanged, this, &ResourcesUpdatesModel::etaChanged);
             connect(updater, &AbstractBackendUpdater::downloadSpeedChanged, this, &ResourcesUpdatesModel::downloadSpeedChanged);
-            connect(updater, &AbstractBackendUpdater::progressingChanged, this, &ResourcesUpdatesModel::slotProgressingChanged);
             connect(updater, &AbstractBackendUpdater::cancelableChanged, this, &ResourcesUpdatesModel::cancelableChanged);
             connect(updater, &AbstractBackendUpdater::resourceProgressed, this, &ResourcesUpdatesModel::resourceProgressed);
             connect(updater, &AbstractBackendUpdater::destroyed, this, &ResourcesUpdatesModel::updaterDestroyed);
@@ -77,6 +77,7 @@ void ResourcesUpdatesModel::slotProgressingChanged(bool progressing)
 {
     Q_UNUSED(progressing);
     Q_ASSERT(m_transaction);
+
     const bool newProgressing = isProgressing();
     if (newProgressing != m_lastIsProgressing) {
         m_lastIsProgressing = newProgressing;
@@ -118,18 +119,50 @@ void ResourcesUpdatesModel::prepare()
     }
 }
 
+void ResourcesUpdatesModel::fetchChangelog()
+{
+    foreach(AbstractBackendUpdater* upd, m_updaters) {
+        if (upd->hasUpdates())
+            upd->fetchChangelog();
+    }
+}
+
+class UpdateTransaction : public Transaction
+{
+public:
+    UpdateTransaction(ResourcesUpdatesModel* parent)
+        : Transaction(parent, nullptr, Transaction::InstallRole)
+        , m_updater(parent)
+    {
+        setCancellable(m_updater->isCancelable());
+        connect(m_updater, &ResourcesUpdatesModel::cancelableChanged, this, [this]() {
+            setCancellable(m_updater->isCancelable());
+        });
+    }
+
+    void cancel() override {
+        m_updater->cancel();
+    }
+
+private:
+    ResourcesUpdatesModel* m_updater;
+};
+
 void ResourcesUpdatesModel::updateAll()
 {
     if(m_updaters.isEmpty())
         emit progressingChanged(false);
     else {
         delete m_transaction;
-        m_transaction = new Transaction(this, nullptr, Transaction::InstallRole);
+        m_transaction = new UpdateTransaction(this);
         TransactionModel::global()->addTransaction(m_transaction);
         Q_FOREACH (AbstractBackendUpdater* upd, m_updaters) {
             if (upd->hasUpdates())
                 QMetaObject::invokeMethod(upd, "start", Qt::QueuedConnection);
         }
+        foreach(auto updater, m_updaters) {
+            connect(updater, &AbstractBackendUpdater::progressingChanged, this, &ResourcesUpdatesModel::slotProgressingChanged, Qt::UniqueConnection);
+        }
     }
 }
 
@@ -150,15 +183,6 @@ QString ResourcesUpdatesModel::remainingTime() const
         return i18nc("@item:intext Remaining time", "%1 remaining", KFormat().formatDuration(maxEta));
 }
 
-bool ResourcesUpdatesModel::hasUpdates() const
-{
-    bool ret = false;
-    foreach(AbstractBackendUpdater* upd, m_updaters) {
-        ret |= upd->hasUpdates();
-    }
-    return ret;
-}
-
 quint64 ResourcesUpdatesModel::downloadSpeed() const
 {
     quint64 ret = 0;
@@ -186,15 +210,6 @@ bool ResourcesUpdatesModel::isProgressing() const
     return progressing;
 }
 
-bool ResourcesUpdatesModel::isAllMarked() const
-{
-    bool allmarked = false;
-    foreach(AbstractBackendUpdater* upd, m_updaters) {
-        allmarked |= upd->isAllMarked();
-    }
-    return allmarked;
-}
-
 QList<AbstractResource*> ResourcesUpdatesModel::toUpdate() const
 {
     QList<AbstractResource*> ret;
