@@ -31,6 +31,7 @@ class QAction;
 class AbstractBackendUpdater;
 class ResourcesModel;
 class QDBusInterface;
+class Transaction;
 
 class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
 {
@@ -47,14 +48,13 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
         
         qreal progress() const;
         QString remainingTime() const;
-        bool hasUpdates() const;
         quint64 downloadSpeed() const;
         Q_SCRIPTABLE void prepare();
+        void fetchChangelog();
 
         ///checks if any of them is cancelable
         bool isCancelable() const;
         bool isProgressing() const;
-        bool isAllMarked() const;
         QList<AbstractResource*> toUpdate() const;
         QDateTime lastUpdate() const;
         void addResources(const QList<AbstractResource*>& resources);
@@ -80,16 +80,14 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
     private Q_SLOTS:
         void updaterDestroyed(QObject* obj);
         void message(const QString& msg);
-        void addNewBackends();
         void slotProgressingChanged(bool progressing);
 
     private:
-        void setResourcesModel(ResourcesModel* model);
+        void init();
 
-        ResourcesModel* m_resources;
         QVector<AbstractBackendUpdater*> m_updaters;
         bool m_lastIsProgressing;
-        QDBusInterface * m_kded;
+        Transaction* m_transaction;
 };
 
 #endif // RESOURCESUPDATESMODEL_H
